@@ -4,7 +4,7 @@
 # 
 # Copyright (C) 2004 Alastair McKinstry <mckinstry@debian.org>
 # Released under the GPL.
-# $Id: iso3166tab.py,v 1.1 2004/05/20 21:24:39 mckinstry Exp $
+# $Id: iso3166tab.py,v 1.2 2005/01/08 18:06:46 mckinstry Exp $
 
 from xml.sax import saxutils, make_parser, saxlib, saxexts, ContentHandler
 from xml.sax.handler import feature_namespaces
@@ -47,7 +47,7 @@ p.setErrorHandler(saxutils.ErrorPrinter())
 try:
 	dh = printLines(ofile)
 	p.setContentHandler(dh)
-	p.parse('iso_3166.xml')
+	p.parse(sys.argv[1])
 except IOError,e:
 	print in_sysID+": "+str(e)
 except saxlib.SAXException,e:
